/**
* @file utils.h
*
* Copyright (C) 2020. Huawei Technologies Co., Ltd. All rights reserved.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/
#pragma once
#include <string>
#include <iostream>
#include <vector>
#include "acl/acl.h"

#include "logColors.h"

#define INFO_LOG(fmt, ...) fprintf(stdout, INFO_SUCCESS "[INFO]  " fmt "\n", ##__VA_ARGS__)
#define WARN_LOG(fmt, ...) fprintf(stdout, INFO_LOADING "[WARN]  " fmt "\n", ##__VA_ARGS__)
#define ERROR_LOG(fmt, ...)fprintf(stderr, INFO_FAILED "[ERROR]  " fmt "\n", ##__VA_ARGS__)

typedef enum Result {
    SUCCESS = 0,
    FAILED = 1
} Result;

class Utils {
public:
    /**
     * @brief check for validation of acl status
     * @param [in] status: acl status
     * @return true if status is ACL_SUCCESS, false otherwise
    */
    static bool validStatus(const char* msg, const aclError& status);

    /**
    * @brief create buffer of file
    * @param [in] fileName: file name
    * @param [out] inputBuff: input data buffer
    * @param [out] fileSize: size of file
    * @return result
    */
    static Result ReadBinFile(const std::string &fileName, void *&inputBuff, uint32_t &fileSize);

    /**
    * @brief create buffer of file
    * @param [in] fileName: file name
    * @param [out] picDevBuffer: input data device buffer which need to be memcpy
    * @param [out] inputBuffSize: size of inputBuff
    * @return result
    */
    static Result MemcpyFileToDeviceBuffer(const std::string &fileName, void *&picDevBuffer, size_t inputBuffSize);
    static Result MemcpyVariableToDeviceBuffer(std::vector<float> VectorVariable, void *&picDevBuffer, size_t inputBuffSize);
    static Result MemcpyVariableToDeviceBuffer(std::vector<int32_t> VectorVariable, void *&picDevBuffer, size_t inputBuffSize);
    
    static std::vector<int64_t> ZeroPadding (std::vector<int64_t> coords_data);

    static void convert64to32(const std::vector<int64_t>& num_points_data, std::vector<int32_t>& num_points_data32);
    /**
    * @brief Check whether the path is a file.
    * @param [in] fileName: fold to check
    * @return result
    */
    static Result CheckPathIsFile(const std::string &fileName);
};

#pragma once
